@@ -28,31 +28,22 @@ MONTH_AVG_VOL_SEARCH = rc(r"QTotTran5JAvg='(\d+)'").search
 FIRST_NUMBER_SEARCH = rc(r'\d+').search
 INSTANT_MATCH = rc(
     r'(?P<timestamp>\d\d:\d\d:\d\d),'
-    r'A ,'
-    r'(?P<last_price>\d+),'
-    r'(?P<closing_price>\d+),'
-    r'(?P<opening_price>\d+),'
-    r'(?P<yesterday_price>\d+),'
-    r'(?P<day_range_start>\d+),'
-    r'(?P<day_range_end>\d+),'
-    r'(?P<number_of_transactions>\d+),'
-    r'(?P<volume_of_transactions>\d+),'
-    r'(?P<value_of_transactions>\d+),'
+    r'..,'
+    r'(?P<pl>\d+),'
+    r'(?P<pc>\d+),'
+    r'(?P<pf>\d+),'
+    r'(?P<py>\d+),'
+    r'(?P<pmin>\d+),'
+    r'(?P<pmax>\d+),'
+    r'(?P<tno>\d+),'
+    r'(?P<tvol>\d+),'
+    r'(?P<tval>\d+),'
     r'1,'
     r'(?P<last_info_datetime>\d+,\d+)'
     r'(,(?P<nav_datetime>[\d\/: ]+),(?P<nav>\d+))?'
 ).match
 INSTANT_INTS = {
-    'last_price',
-    'closing_price',
-    'opening_price',
-    'yesterday_price',
-    'day_range_start',
-    'day_range_end',
-    'number_of_transactions',
-    'volume_of_transactions',
-    'value_of_transactions',
-}
+    'pl', 'pc', 'py', 'pf', 'py', 'pmin', 'pmax', 'tno', 'tvol', 'tval'}
 
 
 def get_content(url) -> bytes:
@@ -106,9 +97,12 @@ class Instrument:
         }
 
     def get_inst_info(self) -> dict:
+        # apparently, http://www.tsetmc.com/tsev2/data/instinfodata.aspx?i=...
+        # and http://www.tsetmc.com/tsev2/data/instinfofast.aspx?i=...
+        # return the same response.
         text = fa_norm_text(
             f'http://www.tsetmc.com/tsev2/data/instinfodata.aspx'
-            f'?i={self.id}&c=67%20')
+            f'?i={self.id}&c=')
         group_dict = INSTANT_MATCH(text).groupdict()
         for k in INSTANT_INTS:
             # noinspection PyTypeChecker
@@ -138,6 +132,9 @@ def get_market_watch_init() -> dict:
         https://cdn.tsetmc.com/Site.aspx?ParTree=151713
         For `flow` and `yval` codes see:
             http://cdn.tsetmc.com/Site.aspx?ParTree=1114111118&LnkIdn=83
+        For `heven` see:
+            http://cdn.tsetmc.com/Site.aspx?ParTree=111411111S&LnkIdn=129
+            (it's the time of last transaction in HHMMSS format)
     """
     text = fa_norm_text('http://tsetmc.com/tsev2/data/MarketWatchInit.aspx?h=0&r=0')
     _, _, states, price_rows, _ = text.split('@')
@@ -145,8 +142,8 @@ def get_market_watch_init() -> dict:
         StringIO(states),
         lineterminator=';',
         names=(
-            'id', 'isin', 'l18', 'l30', 'unknown1', 'pf', 'pc', 'pl', 'tno',
-            'tvol', 'tval', 'pmin', 'pmax', 'py', 'eps', 'bvol', 'unknown2',
+            'id', 'isin', 'l18', 'l30', 'heven', 'pf', 'pc', 'pl', 'tno',
+            'tvol', 'tval', 'pmin', 'pmax', 'py', 'eps', 'bvol', 'visitcount',
             'flow', 'cs', 'tmax', 'tmin', 'z', 'yval'),
         # unlike int64, Int64 is nullable
         dtype={'tmin': "Int64", 'tmax': "Int64"},
@@ -170,7 +167,7 @@ def get_market_watch_init() -> dict:
     }
 
 
-def _split_id_rows(content: bytes, id_row_len):
+def _split_id_rows(content: bytes, id_row_len: int) -> list:
     data = content.split(b';')
     for i, datum in enumerate(data):
         items = datum.split(b',')
